searchData={"items":[{"type":"module","title":"EctoEnumMigration","doc":"Provides a DSL to easily handle Postgres Enum Types in Ecto database migrations.","ref":"EctoEnumMigration.html"},{"type":"function","title":"EctoEnumMigration.add_value_to_type/3","doc":"Add a value to a existing Postgres type.\n\nThis operation is not reversible, existing values cannot be removed from an enum type.\nCheckout [Enumerated Types](https://www.postgresql.org/docs/current/datatype-enum.html)\nfor more information.\n\nAlso if running on a version of Postgres <= 11 then it cannot be used inside\na transaction block, so we need to set `@disable_ddl_transaction true` in the migration.","ref":"EctoEnumMigration.html#add_value_to_type/3"},{"type":"function","title":"Examples - EctoEnumMigration.add_value_to_type/3","doc":"```elixir\ndefmodule MyApp.Repo.Migrations.AddValueToTypeMigration do\n  use Ecto.Migration\n  import EctoEnumMigration\n  # Only needed if running on Postgres <= 11\n  @disable_ddl_transaction true\n\n  def up do\n    add_value_to_type(:status, :finished)\n  end\n\n  def down do\n  end\nend\n```\n\nBy default the type will be created in the `public` schema.\nTo change the schema of the type pass the `schema` option.\n\n```elixir\nadd_value_to_type(:status, :finished, schema: \"custom_schema\")\n```\n\nIf the new value's place in the enum's ordering is not specified,\nthen the new item is placed at the end of the list of values.\n\nBut we specify the the place in the ordering for the new value with the\n`:before` and `:after` options.\n\n```elixir\nadd_value_to_type(:status, :finished, before: :started)\n```\n\n```elixir\nadd_value_to_type(:status, :finished, after: :started)\n```\n\nCan specify to only add value if not exists with the `:if_not_exists` option\n\n```elixir\nadd_value_to_type(:status, :finished, if_not_exists: true)\n```","ref":"EctoEnumMigration.html#add_value_to_type/3-examples"},{"type":"function","title":"EctoEnumMigration.create_type/3","doc":"Create a Postgres Enum Type.","ref":"EctoEnumMigration.html#create_type/3"},{"type":"function","title":"Examples - EctoEnumMigration.create_type/3","doc":"```elixir\ndefmodule MyApp.Repo.Migrations.CreateTypeMigration do\n  use Ecto.Migration\n  import EctoEnumMigration\n\n  def change do\n    create_type(:status, [:registered, :active, :inactive, :archived])\n  end\nend\n```\n\nBy default the type will be created in the `public` schema.\nTo change the schema of the type pass the `schema` option.\n\n```elixir\ncreate_type(:status, [:registered, :active, :inactive, :archived], schema: \"custom_schema\")\n```","ref":"EctoEnumMigration.html#create_type/3-examples"},{"type":"function","title":"EctoEnumMigration.drop_type/2","doc":"Drop a Postgres Enum Type.\n\nThis command is not reversible, so make sure to include a `down/0` step in the migration.","ref":"EctoEnumMigration.html#drop_type/2"},{"type":"function","title":"Examples - EctoEnumMigration.drop_type/2","doc":"```elixir\ndefmodule MyApp.Repo.Migrations.DropTypeMigration do\n  use Ecto.Migration\n  import EctoEnumMigration\n\n  def up do\n    drop_type(:status)\n  end\n\n  def down do\n    create_type(:status, [:registered, :active, :inactive, :archived])\n  end\nend\n```\n\nBy default the type will be created in the `public` schema.\nTo change the schema of the type pass the `schema` option.\n\n```elixir\ndrop_type(:status, schema: \"custom_schema\")\n```","ref":"EctoEnumMigration.html#drop_type/2-examples"},{"type":"function","title":"EctoEnumMigration.rename_type/3","doc":"Rename a Postgres Type.","ref":"EctoEnumMigration.html#rename_type/3"},{"type":"function","title":"Examples - EctoEnumMigration.rename_type/3","doc":"```elixir\ndefmodule MyApp.Repo.Migrations.RenameTypeMigration do\n  use Ecto.Migration\n  import EctoEnumMigration\n\n  def change do\n    rename_type(:status, :status_renamed)\n  end\nend\n```\n\nBy default the type will be created in the `public` schema.\nTo change the schema of the type pass the `schema` option.\n\n```elixir\nrename_type(:status, :status_renamed, schema: \"custom_schema\")\n```","ref":"EctoEnumMigration.html#rename_type/3-examples"},{"type":"function","title":"EctoEnumMigration.rename_value/4","doc":"Rename a value of a Postgres Type.\n\n***Only compatible with Postgres version 10+***","ref":"EctoEnumMigration.html#rename_value/4"},{"type":"function","title":"Examples - EctoEnumMigration.rename_value/4","doc":"```elixir\ndefmodule MyApp.Repo.Migrations.RenameTypeMigration do\n  use Ecto.Migration\n  import EctoEnumMigration\n\n  def change do\n    rename_value(:status, :finished, :done)\n  end\nend\n```\n\nBy default the type will be created in the `public` schema.\nTo change the schema of the type pass the `schema` option.\n\n```elixir\nrename_value(:status, :finished, :done, schema: \"custom_schema\")\n```","ref":"EctoEnumMigration.html#rename_value/4-examples"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}